summaryrefslogtreecommitdiff
path: root/inc/storage.h
diff options
context:
space:
mode:
Diffstat (limited to 'inc/storage.h')
-rw-r--r--inc/storage.h17
1 files changed, 15 insertions, 2 deletions
diff --git a/inc/storage.h b/inc/storage.h
index a30e74d..fc93d7a 100644
--- a/inc/storage.h
+++ b/inc/storage.h
@@ -14,15 +14,22 @@ class Storage
virtual ~Storage() = default;
/**
- * Write `data` into `address`.
+ * Write `data` word into `address`.
* @param the source making the request.
* @param the data (hexadecimal) to write.
* @param the address to write to.
* @return a status code reflecting the state of the request.
*/
virtual Response write(Accessor accessor, signed int data, int address) = 0;
+
+ /**
+ * Write a data line to given address in this level of storage
+ */
+ virtual Response write_line(Accessor accessor, std::array<signed int, LINE_SIZE> data_line, int address) = 0;
+
+
/**
* Get the data at `address`.
* @param the source making the request.
* @param the address being accessed.
* @return a status code reflecting the state of the request, and the
@@ -32,6 +39,12 @@ class Storage
Accessor accessor,
int address,
std::array<signed int, LINE_SIZE> &data) = 0;
+
+ /**
+ * Read a word from given address in this level of storage
+ */
+ virtual Response read_word(Accessor accessor, int address, signed int &data) = 0;
+
/**
* Sidedoor view of `lines` of memory starting at `base`.
* @param The base line to start getting memory from.
@@ -14,15 +14,22 @@ class Storage
/**
- * Get the data at `address`.
+ * Get the data line at `address`.
* @param the source making the request.
* @param the address being accessed.